CursorManager class

The cursor manager

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteCursor(String name) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCursor(CursorData data) → Future<String>
Note The documentation from engine/shell/platform/cursor_handler.cc.
setSystemCursor(String name) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CursorManager
getter/setter pair

Constants

channel → const MethodChannel
createCursorKey → const String
deleteCursorMethod → const String
setCursorMethod → const String